Emperor

# WebGL is not enabled!

Emperor's visualization framework is WebGL based, it seems that your system doesn't have this resource available. Here is what you can do:

Chrome: Type "chrome://flags/" into the address bar, then search for "Disable WebGL". Disable this option if you haven't already. Note: If you follow these steps and still don't see an image, go to "chrome://flags/" and then search for "Override software rendering list" and enable this option.

Safari: Open Safari's menu and select Preferences. Click on the advanced tab, and then check "Show Developer" menu. Then open the "Developer" menu and select "Enable WebGL".

Firefox: Go to Options through Firefox > Options or Tools > Options. Go to Advanced, then General. Check "Use hardware acceleration when available" and restart Firefox.

Other browsers: The only browsers that support WebGL are Chrome, Safari, and Firefox. Please switch to these browsers when using Emperor.

Note: Once you went through these changes, reload the page and it should work!

Sources: Instructions for Chrome and Safari, and Firefox

PCoA Parallel